Template for advanced microcontrollers assignment 'DMA' 2017

Dependencies:   SimpleDMA

Files at this revision

API Documentation at this revision

Comitter:
wkleunen
Date:
Mon Oct 16 18:58:17 2017 +0000
Parent:
1:1db1c42a2348
Commit message:
Revert incorrect comment

Changed in this revision

main.cpp Show annotated file Show diff for this revision Revisions of this file
diff -r 1db1c42a2348 -r 9567c0734e96 main.cpp
--- a/main.cpp	Mon Oct 16 18:55:27 2017 +0000
+++ b/main.cpp	Mon Oct 16 18:58:17 2017 +0000
@@ -8,6 +8,7 @@
 DigitalOut led1(LED_RED);
 DigitalOut led2(LED_GREEN);
 
+SimpleDMA dma_pc;
 SimpleDMA dma_device;
     
 int main() 
@@ -16,7 +17,7 @@
     UART1->C2 |= UART_C2_RIE_MASK | UART_C2_TIE_MASK ;  
     UART1->C4 |= UART_C4_RDMAS_MASK | UART_C4_TDMAS_MASK;
   
-    // TODO: Configure dma_device to transfer data from buffer to UART1
+    // TODO: Configure dma_device to transfer data from UART1 to UART0
     // ...
     
     uint8_t buffer[128];
@@ -34,7 +35,7 @@
             
             led2 = !led2;
             
             // TODO: Trigger dma_device to transfer data from the buffer to UART1
             // ....
             
             buffer_ptr = 0;
@@ -34,7 +35,7 @@
             led2 = !led2;
             
-            // TODO: Trigger dma_device to transfer data from the buffer to UART1
+            // TODO: Trigger dma_pc to transfer data from the buffer to UART1
             // ....
             